@@ -1,4 +1,4 @@
-/* 
+/*
  * Copyright © 2005 Jean-Yves Lefort <jylefort@brutele.be>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -19,8 +19,7 @@
 #ifndef _EPHY_ACTIONS_EXTENSION_EDITOR_DIALOG_H
 #define _EPHY_ACTIONS_EXTENSION_EDITOR_DIALOG_H
 
-#include <epiphany/ephy-dialog.h>
-#include <epiphany/ephy-extension.h>
+#include <epiphany/epiphany.h>
 
 G_BEGIN_DECLS
 
