@@ -24,8 +24,7 @@
 #include <glib-object.h>
 #include <gtk/gtk.h>
 
-#include <epiphany/ephy-embed.h>
-#include <epiphany/ephy-window.h>
+#include <epiphany/epiphany.h>
 
 G_BEGIN_DECLS
 
